## **Journal of Sports Sciences**

**[ISSN: 0264-0414 (Print) 1466-447X (Online) Journal homepage: http://www.tandfonline.com/loi/rjsp20](http://www.tandfonline.com/loi/rjsp20)**

# **Concurrent validity and reliability of an iPhone app** **for the measurement of ankle dorsiflexion and** **inter-limb asymmetries iPhone**

**Carlos Balsalobre-Fernández, Natalia Romero-Franco & Pedro Jiménez-Reyes**

**To cite this article:** Carlos Balsalobre-Fernández, Natalia Romero-Franco & Pedro JiménezReyes (2018): Concurrent validity and reliability of an iPhone app for the measurement of
ankle dorsiflexion and inter-limb asymmetries iPhone, Journal of Sports Sciences, DOI:
[10.1080/02640414.2018.1494908](http://www.tandfonline.com/action/showCitFormats?doi=10.1080/02640414.2018.1494908)

**To link to this article:** [https://doi.org/10.1080/02640414.2018.1494908](https://doi.org/10.1080/02640414.2018.1494908)

Published online: 02 Jul 2018.

[Submit your article to this journal](http://www.tandfonline.com/action/authorSubmission?journalCode=rjsp20&show=instructions)

[View Crossmark data](http://crossmark.crossref.org/dialog/?doi=10.1080/02640414.2018.1494908&domain=pdf&date_stamp=2018-07-02)

Full Terms & Conditions of access and use can be found at
[http://www.tandfonline.com/action/journalInformation?journalCode=rjsp20](http://www.tandfonline.com/action/journalInformation?journalCode=rjsp20)

JOURNAL OF SPORTS SCIENCES

<https://doi.org/10.1080/02640414.2018.1494908>

### Concurrent validity and reliability of an iPhone app for the measurement of ankle dorsiflexion and inter-limb asymmetries iPhone

Carlos Balsalobre-Fernández a,b, Natalia Romero-Francoc and Pedro Jiménez-Reyesd

aDepartment of Physical Education, Sport and Human Movement, Universidad Autónoma de Madrid, Madrid, Spain; bLaboratory of Exercise
Physiology Research Group, Department of Health and Human Performance, School of Physical Activity and Sport Sciences-INEF, Universidad
Politécnica de Madrid, Madrid, Spain; \[c\] Nursing and Physiotherapy Department, University of the Balearic Islands, Palma de Mallorca, Spain;
dFaculty of Sport, Catholic University of San Antonio, Murcia, Spain

ABSTRACT
The purpose of this investigation was to analyze the validity and reliability of an iPhone app (named:
Dorsiflex) for the measurement of weight-bearing ankle dorsiflexion. To do this, twelve healthy
participants (age=28.6±2.3 years) performed a weight-bearing lunge test with each leg in five separate
occasions, while dorsiflexion angle was simultaneously registered using a professional digital inclinometer and the Dorsiflex iPhone app, which was specifically developed for this study. A total of 120
angles measured both with the digital inclinometer and the app were then compared for validity,
reliability and accuracy purposes using several statistical tests. There was an almost perfect correlation
between the digital inclinometer and the Dorsiflex app for the measurement of ankle dorsiflexion
(r=0.989, 95% CI=0.986-0.993, SEE=0.48º), with trivial, non-significant differences between devices
(SMD=0.17, p=0.10). When analyzing the reliability of the app for the measurement of five different
trials for each participant, similar coefficients of variation (CV) were observed in comparison with those
obtained with the digital inclinometer (Dorsiflex app: CV=5.1±2.3 %; Digital inclinometer: CV=4.9±2.5
%). The results of the present study show that weight-bearing ankle dorsiflexion can be easily,
accurately, and reliably evaluated using the Dorsiflex iPhone app.

ARTICLE HISTORY
Accepted 26 June 2018

KEYWORDS
Injury; biomechanics;
technology; smartphone;
foot

Introduction

Several closed-chain tasks, like squatting or landing a vertical
jump produce an important amount of force that lower-limb
joints need to absorb in the sagittal plane (Devita & Skelly,
1992\) When weight-bearing ankle dorsiflexion (WBDF) is
restricted, the range of motion of the knee and the trunk in
the sagittal plane is often reduced, producing compensation
forces in the frontal and transverse planes that could lead to
injuries (Bell-Jenje et al., 2016; Dill, Begalle, Frank, Zinder, &
Padua, 2014; Ota, Ueda, Aimoto, Suzuki, & Sigward, 2014). For
example, it was observed that reduced WBDF significantly
alters landing kinematics after a vertical jump, producing
excessive knee valgus that ultimately could increase the risk
of anterior cruciate ligament tears (Dill et al., 2014). It is also
known that reduced ankle dorsiflexion is one of the main

factors that lead to plantar fasciitis (Riddle, Pulisic, Pidcoe, &
Johnson, 2003). For this, many authors have proposed the
WBDF measurement as a relevant clinical parameter to evaluate the risk of suffering lower limb injuries (Malloy, Meinerz,
Geiser, & Kipp, 2015; Mason-Mackay, Whatman, & Reid, 2017),
since several types seems to be related with limited WBDF,
such as patellar tendinopathy (Malliaras, Cook, & Kent, 2006),
anterior cruciate ligament tears (Amraee, Alizadeh,
Minoonejhad, Razi, & Amraee, 2017) or plantar fasciitis
(Riddle et al., 2003), among others. Moreover, limited WBDF

contributes to movement dysfunction in such a way that
predisposes the athlete to a higher risk of recurrence
(Grindstaff, Dolan, & Morton, 2017; Scattone Silva et al., 2016;

Wahlstedt & Rasmussen-Barr, 2015).

Considering the clinical relevance of the evaluation of
WBDF for injury prevention and rehabilitation purposes, several methodologies have been used to measure dorsiflexion
range of motion under field conditions, such as knee-to-wall
tests, goniometers or digital inclinometers (Bennell et al., 1998;
Hoch & McKeon, 2011; Konor, Morton, Eckerson, & Grindstaff,
2012; Powden, Hoch, & Hoch, 2015). Among them, it seems
that the use of digital inclinometers is gaining popularity,
since they provide accurate measures almost instantly without
the need of manually inspecting the distance from the toes to
a wall or the angles measured using a goniometer (Konor
et al., 2012). Furthermore, the rise of smartphones, which
include several sensors to measure movement, such as accelerometers or gyroscopes, have allowed researchers to measure the range of motion of different joints of the human body
in a valid, reliable way (Charlton, Mentiplay, Pua, & Clark, 2015;
Milani et al., 2014; Mizuno et al., 2013; Peart, BalsalobreFernández, & Shaw, 2017). For example, it was observed that
a smartphone application was valid and reliable for the measurement of seven different angles of the hip in comparison
with a three-dimensional motion capture system (Charlton
et al., 2015). However, to the best of our knowledge, no

CONTACT Carlos Balsalobre-Fernández <carlos.balsalobre@icloud.com> Department of Physical Education, Sport and Human Movement, Universidad
Autónoma de Madrid, C/Fco Tomas y Valiente 3, 28049, Cantoblanco, Madrid, Spain

© 2018 Informa UK Limited, trading as Taylor & Francis Group

2 C. BALSALOBRE-FERNÁNDEZ ET AL.

existing applications designed to evaluate WBDF, leg asymmetry and to provide instant feedback to the user/clinician
have been analyzed in the literature. For this, the purpose of
the present study was to analyze the validity and reliability of
an iPhone app specifically designed to measure weight-bearing ankle dorsiflexion and leg asymmetry in comparison with a
professional digital dynamometer.

Methods

Participants

The participants in the present study were 12 healthy, physically active individuals, with at least 4 years of training background (N = 12; 7 males, 5 females; age = 28.6 ± 2.3 years,
height = 1.71 ± 0.04 m; body mass = 64.9 ± 7.8 kg). The study
protocol complied with the Declaration of Helsinki for Human
Experimentation and was approved by the ethics committee
at the institutional review board. Written informed consent

was obtained from each participant in advance.

Study design

During a single morning, and without any kind of warm-up,
participants performed the weight-bearing lunge test in order
to determine their ankle dorsiflexion angle as reported elsewhere (Hoch & McKeon, 2011). Both a validated, professional
digital inclinometer (Limit® mini digital inclinometer, Alingsas,
Sweden) and the recently developed Dorsiflex iPhone app
were used simultaneously by an experienced physical therapist (i.e., attaching the devices to the same leg) to measure
ankle dorsiflexion of each athlete. Participants’ dorsiflexion
was measured both for their dominant and non-dominant

leg (in a random order) on five different occasions separated
by 10 minutes of passive rest. Therefore, 10 different angles
were registered for each athlete with each instrument, for a
total of 240 comparison points. Finally, dorsiflexion angles
measured with both systems were compared for validity and
reliability purposes using several statistical analyses as recommended in previous investigations (Balsalobre-Fernández,
Glaister, & Lockey, 2015; Bland & Altman, 1999).

Instruments

A Limit® mini digital inclinometer (Alingsas, Sweden) (RomeroFranco, Montaño-Munuera, & Jiménez-Reyes, 2017) was used
as the reference system in the present study, and a newly
developed iPhone application was compared to it for validity,
reliability and accuracy purposes. To measure dorsiflexion
angle, the digital inclinometer was placed right under the
tibial tuberosity.

The app (named: Dorsiflex) was specifically developed for
this study using Xcode 9.2 for macOS High Sierra 10.3.3 and
the Swift 4 programming language (Apple Inc., USA). The
CoreMotion framework (Apple Inc., USA) was used for capturing the inclination angles of the iPhone using 3-axis gyroscope
data at a sampling frequency of 200Hz. Then, the app (version
1.0) was installed on an iPhone 8 running iOS 11.2 (Apple Inc.,
USA). To measure dorsiflexion angle, the app asked the

participant to move into a weight bearing lunge position, to
put the device with the screen touching the tibia (under the
tibial tuberosity, aligning the Z-axis of the phone with the
tibia) and to click “GO!”. Then, the app started a countdown
of 5 seconds and, when completed, it registered the inclination angle in the X-axis of the iPhone (i.e., the imaginary line
that goes from the left to the right of the screen). After
repeating this procedure with both legs, the app reported
the dorsiflexion angle of each leg, as well as the percent of
asymmetry between legs. See Figure 1 for more details.

Statistical analyses

First, the app’s concurrent validity was tested using Pearson’s

–
product moment correlation coefficient (r) with 90% confidence intervals (CI) via N = 1000 bootstrapping. Second, to
analyze the level of agreement (reliability) between the app
and the digital inclinometer for the measurement of dorsiflexion angle and leg asymmetry, the intraclass correlation coefficient (ICC) with 90% CI and Cronbach’s alpha were used. Also,

–
paired samples T-test and Bland Altman plots were used to
identify potential systematic bias, reported via mean bias,
standard deviations and the analysis of the regression line
on the Bland–Altman plots. Furthermore, standard error of
estimate (SEE) was also used to report the typical error in
the measurements. The standardized mean difference (SMD)

between the measures obtained with each instrument was

calculated using Cohen’s d effect size and reported as trivial

– – –
(0 0.2), small (0.2 0.6), moderate (0.6 1.2) or large (> 1.2).
Finally, when analyzing the reproducibility of the Dorsiflex
app for the measurement of the 5 different trials conducted,
the coefficient of variation (CV) was used. The level of significance was set at 0.05. All calculations were performed using
IBM® SPSS® Statistics 22 software (IBM Co., USA).

Results

Concurrent validity

The analysis of the whole dataset (i.e., 120 individual points)
showed a very high correlation between the Dorsiflex app and
the digital inclinometer for the measurement of dorsiflexion

–
angle (r = 0.989, 95% CI = 0.986 0.993, Slope of the regression
line = 1.0002, p \< 0.001, SEE = 0.48º). See Figure 2.

Trivial, non-significant differences between the values
obtained with each instrument were observed as revealed by
the paired-samples T-test (SMD = 0.16; Mean difference = 0.54 ± 0.4 º; Dorsiflex app: 35.7 ± 3.2 º; Digital inclinometer: 35.2 ± 3.3 º, p = 0.10). Moreover, the analysis of the
regression line when plotting the mean of the two instruments vs. the difference between the two instruments (i.e.,
Bland-Altman plot) showed that the systematic bias was similar between the whole range of angles measured (R \[2\] = 0.005).
See Figure 3.

Reliability

The ICC showed a very high agreement between the dorsiflexion angles registered by the Dorsiflex app in comparison

JOURNAL OF SPORTS SCIENCES 3

Figure 1. User interface of the app analyzed in the study. A) Instructions to proceed with the weight-bearing lunge test and B) results screen showing instant
feedback about ankle dorsiflexion and inter-limb asymmetry.

Figure 2. Correlation plot with regression line between the dorsiflexion angles
obtained with the Dorsiflex app and the digital inclinometer.

–
with the digital inclinometer (ICC = 0.976, 95%CI = 0.966
0.983, Cronbach’s alpha = 0.995). Finally, when analyzing the
reproducibility of the Dorsiflex app for the measurement of 5
different trials, similar coefficients of variation were observed
in comparison with those obtained with the digital inclinometer (Dorsiflex app: CV = 5.1 ± 2.3%; Digital inclinometer:
CV = 4.9 ± 2.5%).

Figure 3. Bland-Altman plot showing the bias (± 1.96 SD) between instruments
and the regression line of the residuals (dashed line).

Measurement of dorsiflexion asymmetry

When analyzing the ability of each instrument to detect asymmetries between the dominant and non-dominant foot in the

dorsiflexion angle, a very high relationship between Dorsiflex
app and the digital inclinometer, as well as trivial standardized
mean differences were observed (Dorsiflex app: 5.6 ± 5.4º;

4 C. BALSALOBRE-FERNÁNDEZ ET AL.

–
Digital inclinometer: 5.4 ± 5.2º; r = 0.942, 95% CI = 0.880
0.968, SMD = 0.03, p = 0.378).

Discussion

The Dorsiflex app was found to be very valid, reliable and
accurate for the measurement of ankle dorsiflexion in comparison with a professional inclinometer. Specifically, data
showed an almost perfect association between the dorsiflexion angles obtained with the app in comparison with the
inclinometer as revealed by Pearson’s product-moment correlation coefficient and its narrow 95% CI via N = 1000 boot
–
strapping (r = 0.986 0.993). Moreover, the slope of the
regression line (which was very close to de identity line)
revealed that the values obtained with the app were indeed
very similar to those measured with the inclinometer, as
further confirmed by the paired-samples T-test (mean difference = 0.54º, p = 0.10) and the effect size of the differences
(SMD = 0.16, i.e., trivial effect). Furthermore, the analysis of the
regression line of the Bland-Altman plot showed that the
differences between the app and the digital inclinometer
were stable across the whole range of angles analyzed, meaning that reported mean differences between devices are
expected to be similar in participants with different levels of
ankle dorsiflexion. Also, when testing the reproducibility of the
app across 5 separate trials for each participant, similar coefficients of variation than the digital inclinometer were observed
(about 5%). Taken together, these results demonstrate that an
iPhone application can be used to obtain highly valid, reliable
and accurate measures of ankle dorsiflexion without any professional equipment. These results are in line with several
studies that showed similar levels of association between

smartphone applications and professional inclinometers, goniometers or 3D systems for the measurement of different
ranges of motion of the human body (Charlton et al., 2015;
Milani et al., 2014; Peart et al., 2017; Vohralik, Bowen, Burns,
Hiller, & Nightingale, 2015). For example, an Android application was showed to provide reliable data of seven different
measurers of hip range of motion in comparison with a threedimensional motion analysis system (Charlton et al., 2015).
Thus, this study adds to a growing body of research that
highlights the validity and reliability of the sensors included
in smartphones or wearable devices for the measurement of
human movement (Peart et al., 2017). However, considering
that the Dorsiflex app can be installed on devices with very
different screen sizes (from 4 inches iPhone to 12.9 inches
iPad), a main limitation of the present investigation is that
the app was just tested on the iPhone 8. It is unknown if a
device with a larger display like the iPad Pro could be placed
as easily as the iPhone on the tibia to provide accurate measures of ankle dorsiflexion. Thus, more research is needed to
determine the validity and reliability of the Dorsiflex app in
devices with larger displays.

Another relevant finding of the present study was the
ability of the app to detect between-leg asymmetries in
comparison with a digital inclinometer. Both the app and
the digital inclinometer showed asymmetries in the dorsiflexion range of motion of about 5%, with trivial, non-significant differences between devices (Mean difference: 0.2º;

r = 0.942, SMD = 0.03, p = 0.378). Lower limb asymmetry has
been identified as one of the factors that might increase the
risk of injury (Bishop, Turner, & Read, 2017; Hewit, Cronin, &
Hume, 2012; Zifchock, Davis, Higginson, & Royer, 2008), and
monitoring asymmetry scores is a common practice to
objectively quantify how an athlete progresses during a
rehabilitation period (Bishop et al., 2017; Brown et al.,
2017). Also, reduced dorsiflexion on a certain limb was
shown to alter landing mechanics or increase the risk of
suffering plantar fasciitis (Riddle et al., 2003). To the best
of our knowledge, the app analyzed in the present study is
the first one that provides direct feedback of ankle dorsiflexion and leg asymmetry in a valid and reliable way. It
should be noted that the Dorsiflex app is available in
Apple’s AppStore, which can be accessed from hundreds of
millions of devices in the world. Also, the app not only
measure dorsiflexion angle, but it also stores and organizes
the data in its own database without any additional equipment, which could simplify the whole assessment procedure.
These results could have potential practical applications for
strength and conditioning coaches and physical therapists
who wish to monitor their athlete’s ankle dorsiflexion in a

simple way by using their smartphone.

Acknowledgments

The authors want to thank the athletes for their involvement in the

present study.

Disclosure statement

The first author of the article is the developer of the app mentioned. The
data from the app were obtained from an independent observer not
related to the app development.

ORCID

Carlos Balsalobre-Fernández <http://orcid.org/0000-0002-8329-1581>

References

Amraee, D., Alizadeh, M. H., Minoonejhad, H., Razi, M., & Amraee, G. H.

(2017). Predictor factors for lower extremity malalignment and noncontact anterior cruciate ligament injuries in male athletes. Knee
Surgery, Sports Traumatology, Arthroscopy : Official Journal of the
ESSKA, 25(5), 1625–1631.
Balsalobre-Fernández, C., Glaister, M., & Lockey, R. A. (2015). The validity

and reliability of an iPhone app for measuring vertical jump performance. Journal of Sports Sciences, 33(15), 1574–1579.
Bell-Jenje, T., Olivier, B., Wood, W., Rogers, S., Green, A., & McKinon, W.

(2016). The association between loss of ankle dorsiflexion range of
movement, and hip adduction and internal rotation during a step
down test. Manual Therapy, 21, 256–261.
Bennell, K., Talbot, R., Wajswelner, H., Techovanich, W., Kelly, D., & Hall, A.

(1998). Intra-rater and inter-rater reliability of a weight-bearing lunge
measure of ankle dorsiflexion. Australian Journal of Physiotherapy, 44(3),

175–180.

Bishop, C., Turner, A., & Read, P. (2017). Effects of inter-limb asymmetries

on physical and sports performance: A systematic review. Journal of
[Sports Sciences, 1–10. doi:10.1080/02640414.2017.1361894](https://doi.org/10.1080/02640414.2017.1361894)
Bland, J. M., & Altman, D. G. (1999). Measuring agreement in method

comparison studies. Statistical Methods in Medical Research, 8(2), 135–
[160. Retrieved from http://www.ncbi.nlm.nih.gov/pubmed/10501650](http://www.ncbi.nlm.nih.gov/pubmed/10501650)

Brown, S. R., Feldman, E. R., Cross, M. R., Helms, E. R., Marrier, B., Samozino,

P., & Morin, J.-B. (2017). the potential for a targeted strength training
programme to decrease asymmetry and increase performance: A proofof-concept in sprinting. International Journal of Sports Physiology and
[Performance, 1–13. doi:10.1123/ijspp.2016-0590](https://doi.org/10.1123/ijspp.2016-0590)
Charlton, P. C., Mentiplay, B. F., Pua, Y.-H., & Clark, R. A. (2015). Reliability

and concurrent validity of a smartphone, bubble inclinometer and
motion analysis system for measurement of hip joint range of motion.
Journal of Science and Medicine in Sport, 18(3), 262–267.
Devita, P., & Skelly, W. A. (1992). Effect of landing stiffness on joint kinetics

and energetics in the lower extremity. Medicine and Science in Sports
and Exercise, 24(1), 108–115.
Dill, K. E., Begalle, R. L., Frank, B. S., Zinder, S. M., & Padua, D. A. (2014).

Altered knee and ankle kinematics during squatting in those with

–
limited weight-bearing lunge ankle-dorsiflexion range of motion.
Journal of Athletic Training, 49(6), 723–732.
Grindstaff, T. L., Dolan, N., & Morton, S. K. (2017). Ankle dorsiflexion range

of motion influences lateral step down test scores in individuals with
chronic ankle instability. Physical Therapy in Sport : Official Journal of the
Association of Chartered Physiotherapists in Sports Medicine, 23, 75–81.
Hewit, J., Cronin, J., & Hume, P. (2012). Multidirectional leg asymmetry

assessment in sport. Strength and Conditioning Journal, 34(1), 82–86.
Hoch, M. C., & McKeon, P. O. (2011). Normative range of weight-bearing

lunge test performance asymmetry in healthy adults. Manual Therapy,
16(5), 516–519.
Konor, M. M., Morton, S., Eckerson, J. M., & Grindstaff, T. L. (2012).

Reliability of three measures of ankle dorsiflexion range of motion.
International Journal of Sports Physical Therapy, 7(3), 279–287.
Malliaras, P., Cook, J. L., & Kent, P. (2006). Reduced ankle dorsiflexion range

may increase the risk of patellar tendon injury among volleyball
players. Journal of Science and Medicine in Sport / Sports Medicine
Australia, 9(4), 304–309.
Malloy, P., Meinerz, C., Geiser, C., & Kipp, K. (2015). The association of

dorsiflexion flexibility on landing mechanics during a drop vertical
jump. Knee Surgery, Sports Traumatology, Arthroscopy : Official Journal
of the ESSKA, 23(12), 3550–3555.
Mason-Mackay, A. R., Whatman, C., & Reid, D. (2017). The effect of reduced

ankle dorsiflexion on lower extremity mechanics during landing: A
systematic review. Journal of Science and Medicine in Sport, 20(5),

451–458.

Milani, P., Coccetta, C. A., Rabini, A., Sciarra, T., Massazza, G., & Ferriero, G.

(2014). Mobile smartphone applications for body position

JOURNAL OF SPORTS SCIENCES 5

measurement in rehabilitation: A review of goniometric tools. PM & R
[: the Journal of Injury, Function, and Rehabilitation. doi:10.1016/j.](https://doi.org/10.1016/j.pmrj.2014.05.003)
[pmrj.2014.05.003](https://doi.org/10.1016/j.pmrj.2014.05.003)
Mizuno, K., Shiba, Y., Sato, H., Kamide, N., Fukuda, M., & Ikeda, N. (2013).

Validity and reliability of the kinematic analysis of trunk and pelvis
movements measured by smartphones during walking. Journal of
[Physical Therapy Science, 25(1), 97–100. Retrieved from http://search.](http://search.ebscohost.com/login.aspx?direct=true%26AuthType=ip,cookie,url,uid%26db=s3h%26AN=86448542%26lang=es%26site=ehost-live%26scope=site)
[ebscohost.com/login.aspx?direct=true&AuthType=ip,cookie,url,](http://search.ebscohost.com/login.aspx?direct=true%26AuthType=ip,cookie,url,uid%26db=s3h%26AN=86448542%26lang=es%26site=ehost-live%26scope=site)
[uid&db=s3h&AN=86448542&lang=es&site=ehost-live&scope=site](http://search.ebscohost.com/login.aspx?direct=true%26AuthType=ip,cookie,url,uid%26db=s3h%26AN=86448542%26lang=es%26site=ehost-live%26scope=site)
Ota, S., Ueda, M., Aimoto, K., Suzuki, Y., & Sigward, S. M. (2014). Acute

influence of restricted ankle dorsiflexion angle on knee joint mechanics
during gait. The Knee, 21(3), 669–675.
Peart, D. J., Balsalobre-Fernández, C., & Shaw, M. P. (2017). The use of

mobile applications to collect data in sport, health and exercise science.
Journal of Strength and Conditioning Research, 1. [doi:10.1519/](https://doi.org/10.1519/JSC.0000000000002344)

[JSC.0000000000002344](https://doi.org/10.1519/JSC.0000000000002344)

Powden, C. J., Hoch, J. M., & Hoch, M. C. (2015). Reliability and minimal

detectable change of the weight-bearing lunge test: A systematic
review. Manual Therapy, 20(4), 524–532.
Riddle, D. L., Pulisic, M., Pidcoe, P., & Johnson, R. E. (2003). Risk factors for

Plantar fasciitis: A matched case-control study. The Journal of Bone and
Joint Surgery. American Volume, 85–A(5), 872–877. Retrieved from
[http://www.ncbi.nlm.nih.gov/pubmed/12728038](http://www.ncbi.nlm.nih.gov/pubmed/12728038)
Romero-Franco, N., Montaño-Munuera, J. A., & Jiménez-Reyes, P. (2017).

Validity and reliability of a digital inclinometer to assess knee joint
position sense in a closed kinetic chain. Journal of Sport
Rehabilitation, 26(1), jsr.2015–0138.
Scattone Silva, R., Nakagawa, T. H., Ferreira, A. L., Garcia, L. C., Santos, J. E.,

& Serrao, F. V. (2016). Lower limb strength and flexibility in athletes
with and without patellar tendinopathy. Physical Therapy in Sport :
Official Journal of the Association of Chartered Physiotherapists in
Sports Medicine, 20, 19–25.
Vohralik, S. L., Bowen, A. R., Burns, J., Hiller, C. E., & Nightingale, E. J. (2015).

Reliability and validity of a smartphone app to measure joint range.
American Journal of Physical Medicine & Rehabilitation / Association of
Academic Physiatrists, 94(4), 325–330.
Wahlstedt, C., & Rasmussen-Barr, E. (2015). Anterior cruciate ligament

injury and ankle dorsiflexion. Knee Surgery, Sports Traumatology,
Arthroscopy : Official Journal of the ESSKA, 23(11), 3202–3207.
Zifchock, R. A., Davis, I., Higginson, J., & Royer, T. (2008). The symmetry

angle: A novel, robust method of quantifying asymmetry. Gait and
Posture, 27(4), 622–627.
